[tracker/wip/carlosg/parallel-installable: 27/28] tests: Update CLI tests to use tracker3 tool



commit ffd68645ad97916314fd14e455be0e4ff7c9634e
Author: Carlos Garnacho <carlosg gnome org>
Date:   Sun Mar 8 15:12:38 2020 +0100

    tests: Update CLI tests to use tracker3 tool

 tests/functional-tests/cli.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/tests/functional-tests/cli.py b/tests/functional-tests/cli.py
index 63d330384..082336ee2 100644
--- a/tests/functional-tests/cli.py
+++ b/tests/functional-tests/cli.py
@@ -30,26 +30,26 @@ class TestCli(fixtures.TrackerCommandLineTestCase):
     def test_version(self):
         """Check we're testing the correct version of the CLI"""
         output = self.run_cli(
-            ['tracker', '--version'])
+            ['tracker3', '--version'])
 
         version_line = output.splitlines()[0]
         expected_version_line = 'Tracker %s' % configuration.tracker_version()
         self.assertEqual(version_line, expected_version_line)
 
     def test_create_local_database(self):
         """Create a database using `tracker endpoint` for local testing"""
 
         with self.tmpdir() as tmpdir:
             ontology_path = configuration.ontologies_dir()
 
             # Create the database
             self.run_cli(
-                ['tracker', 'endpoint', '--database', tmpdir,
+                ['tracker3', 'endpoint', '--database', tmpdir,
                  '--ontology-path', ontology_path])
 
             # Sanity check that it works.
             self.run_cli(
-                ['tracker', 'sparql', '--database', tmpdir,
+                ['tracker3', 'sparql', '--database', tmpdir,
                  '--query', 'ASK { ?u a rdfs:Resource }'])
 
 
@@ -30,26 +30,26 @@ class TestCli(fixtures.TrackerCommandLineTestCase):
 
     def test_create_local_database(self):
-        """Create a database using `tracker endpoint` for local testing"""
+        """Create a database using `tracker3 endpoint` for local testing"""
 
         with self.tmpdir() as tmpdir:


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]